==> flink-1.20.3-src.tgz: flink-1.20.3/flink-connectors/flink-connector-base/src/test/java/org/apache/flink/connector/base/sink/writer/strategy/NoOpScalingStrategyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.base.sink.writer.strategy;

import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

/** Test class for {@link NoOpScalingStrategy}. */
public class NoOpScalingStrategyTest {
    @Test
    void testScaleUpNoOp() {
        NoOpScalingStrategy scalingStrategy = new NoOpScalingStrategy();

        Integer currentRate = 10;

        assertThat(scalingStrategy.scaleUp(currentRate)).isEqualTo(currentRate);
    }

    @Test
    void testScaleDownNoOp() {
        NoOpScalingStrategy scalingStrategy = new NoOpScalingStrategy();

        Integer currentRate = 10;

        assertThat(scalingStrategy.scaleDown(currentRate)).isEqualTo(currentRate);
    }
}

==> flink-2.2.0-src.tgz: flink-2.2.0/flink-connectors/flink-connector-base/src/test/java/org/apache/flink/connector/base/sink/writer/strategy/NoOpScalingStrategyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.base.sink.writer.strategy;

import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

/** Test class for {@link NoOpScalingStrategy}. */
class NoOpScalingStrategyTest {
    @Test
    void testScaleUpNoOp() {
        NoOpScalingStrategy scalingStrategy = new NoOpScalingStrategy();

        Integer currentRate = 10;

        assertThat(scalingStrategy.scaleUp(currentRate)).isEqualTo(currentRate);
    }

    @Test
    void testScaleDownNoOp() {
        NoOpScalingStrategy scalingStrategy = new NoOpScalingStrategy();

        Integer currentRate = 10;

        assertThat(scalingStrategy.scaleDown(currentRate)).isEqualTo(currentRate);
    }
}
